@@ -1,6 +1,6 @@
 from .User import *
 from .Service import *
-from .Exceptions import ServiceException
+from . import ServiceException
 from .Token import *
 import RDS.Util as Util
 
@@ -12,7 +12,7 @@ def int_or_str(value):
         return value
 
 
-__version__ = "0.2"
+__version__ = "0.3"
 VERSION = tuple(map(int_or_str, __version__.split(".")))
 
 __all__ = [
